==> otyacraftengine-2.10-build9-sources.jar: dev/felnull/otyacraftengine/client/event/OEClientEventHooks.java <==
package dev.felnull.otyacraftengine.client.event;

import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_809;
import net.minecraft.class_989;
import var;

public class OEClientEventHooks {
    public static boolean onRenderHand(class_4587 poseStack, class_4597 multiBufferSource, class_1268 hand, int packedLight, float partialTicks, float interpolatedPitch, float swingProgress, float equipProgress, class_1799 stack) {
        return !MoreRenderEvent.RENDER_ITEM_IN_HAND.invoker().renderItemInHand(poseStack, multiBufferSource, hand, packedLight, partialTicks, interpolatedPitch, swingProgress, equipProgress, stack).isFalse();
    }

    public static boolean onChangeHandHeight(class_1268 hand, class_1799 oldStack, class_1799 newStack) {
        var event = ClientEvent.CHANGE_HAND_HEIGHT.invoker().changeHandHeight(hand, oldStack, newStack);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onPoseHumanoidArm(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        var event = ClientEvent.POSE_HUMANOID_ARM.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onRenderArmWithItem(class_989<? extends class_1309, ? extends class_583<?>> layer, class_1309 livingEntity, class_1799 itemStack, class_809.class_811 transformType, class_1306 humanoidArm, class_4587 poseStack, class_4597 multiBufferSource, int i) {
        var event = MoreRenderEvent.RENDER_ARM_WITH_ITEM.invoker().renderArmWithItem(layer, livingEntity, itemStack, transformType, humanoidArm, poseStack, multiBufferSource, i);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onFabricOBJLoader(class_2960 resourceId) {
        return FabricOBJLoaderEvent.LOAD.invoker().load(resourceId).isTrue();
    }

    public static void onIntegratedServerPauseChange(boolean paused) {
        ClientEvent.INTEGRATED_SERVER_PAUSE.invoker().onPauseChange(paused);
    }
}

==> otyacraftengine-2.15-build9-sources.jar: dev/felnull/otyacraftengine/client/event/OEClientEventHooks.java <==
package dev.felnull.otyacraftengine.client.event;

import java.util.concurrent.atomic.AtomicReference;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_746;
import net.minecraft.class_809;
import net.minecraft.class_989;
import var;

public class OEClientEventHooks {
    public static boolean onRenderHand(class_4587 poseStack, class_4597 multiBufferSource, class_1268 hand, int packedLight, float partialTicks, float interpolatedPitch, float swingProgress, float equipProgress, class_1799 stack) {
        return !MoreRenderEvent.RENDER_ITEM_IN_HAND.invoker().renderItemInHand(poseStack, multiBufferSource, hand, packedLight, partialTicks, interpolatedPitch, swingProgress, equipProgress, stack).isFalse();
    }

    public static boolean onChangeHandHeight(class_1268 hand, class_1799 oldStack, class_1799 newStack) {
        var event = ClientEvent.CHANGE_HAND_HEIGHT.invoker().changeHandHeight(hand, oldStack, newStack);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onPoseHumanoidArm(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        var event = ClientEvent.POSE_HUMANOID_ARM.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
        return event.isEmpty() || event.isTrue();
    }

    public static void onPoseHumanoidArmPost(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        ClientEvent.POSE_HUMANOID_ARM_POST.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
    }

    public static boolean onRenderArmWithItem(class_989<? extends class_1309, ? extends class_583<?>> layer, class_1309 livingEntity, class_1799 itemStack, class_809.class_811 transformType, class_1306 humanoidArm, class_4587 poseStack, class_4597 multiBufferSource, int i) {
        var event = MoreRenderEvent.RENDER_ARM_WITH_ITEM.invoker().renderArmWithItem(layer, livingEntity, itemStack, transformType, humanoidArm, poseStack, multiBufferSource, i);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onFabricOBJLoader(class_2960 resourceId) {
        return FabricOBJLoaderEvent.LOAD.invoker().load(resourceId).isTrue();
    }

    public static void onIntegratedServerPauseChange(boolean paused) {
        ClientEvent.INTEGRATED_SERVER_PAUSE.invoker().onPauseChange(paused);
    }

    public static boolean onHandAttack(class_1799 itemStack) {
        var event = ClientEvent.HAND_ATTACK.invoker().onHandAttack(itemStack);
        return event.isEmpty() || event.isTrue();
    }

    public static ClientEvent.HandRenderSelectionWrapper onEvaluateWhichHandsToRender(ClientEvent.HandRenderSelectionWrapper handRenderSelection, class_746 player) {
        AtomicReference<ClientEvent.HandRenderSelectionWrapper> wrapperAtomicReference = new AtomicReference<>();
        ClientEvent.EVALUATE_RENDER_HANDS.invoker().onEvaluateRenderHands(handRenderSelection, player, wrapperAtomicReference::set);
        var ret = wrapperAtomicReference.get();
        return ret != null ? ret : handRenderSelection;
    }
}
